#libpythonpro

Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br)

[![Build Status](https://travis-ci.org/rbmdesenvolvimento/libpythonpro.svg?branch=master)](https://travis-ci.org/rbmdesenvolvimento/libpythonpro)
[![Updates](https://pyup.io/repos/github/rbmdesenvolvimento/libpythonpro/shield.svg)](https://pyup.io/repos/github/rbmdesenvolvimento/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/rbmdesenvolvimento/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/rbmdesenvolvimento/libpythonpro/)
Suportada versão 3 do Python.

Para instalar:
```console
pip install pipenv
pipenv install --dev
Para conferir qualidade de código:
``` 

Para conferir a qualidade:
```consoles
pipenv run flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
